PyAMG Reference
===============

Multigrid data structure ("The Multilevel Hierarchy")
-----------------------------------------------------

.. currentmodule:: pyamg

.. autosummary::
    :toctree: generated/

    multilevel

Core AMG Methods
----------------

.. currentmodule:: pyamg

.. autosummary::
    :toctree: generated/

    aggregation
    classical

Common AMG Components
---------------------

.. currentmodule:: pyamg

.. autosummary::
    :toctree: generated/

    relaxation
    strength

Helper Routings
---------------

.. currentmodule:: pyamg

.. autosummary::
    :toctree: generated/

    graph
    util

Krylov Methods
--------------

.. currentmodule:: pyamg

.. autosummary::
    :toctree: generated/

    krylov

Gallery Problems
----------------

.. currentmodule:: pyamg

.. autosummary::
    :toctree: generated/

    gallery

amg\_core
----------------

.. currentmodule:: pyamg

.. autosummary::
    :toctree: generated/

    amg_core
